import { select,
        csv,
        scaleLinear,
        max,
        extent,
        axisLeft,
        axisBottom,
        scaleTime,
        format
       } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
const circleRadius = 5;

const render = data => {
  const plotLabel = 'A Week in San Francisco';
  
  const xAxisLabel = 'Time';
  const xValue = d => d.timestamp;
  
  const yAxisLabel = 'Temperature';  
  const yValue = d => d.temperature;
  
  const margin = {top: 60, bottom: 80,right: 40, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();  
  
  const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);  
  
  const yAxisG = g.append('g')
    .call(yAxis);
  
  yAxisG.selectAll('.domain')
  		.remove();
  
  yAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('y',-margin.left/2)
    .attr('x',-innerHeight/2)
  	.attr('fill', 'black')
    .attr('transform',`rotate(-90)`)
  	.style('text-anchor','middle')
  	.text(yAxisLabel);
 
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform',`translate(0,${innerHeight})`);
  	
  xAxisG.select('.domain').remove();

  xAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('y',70)
    .attr('x',innerWidth/2)
  	.attr('fill', 'black')
  	.text(xAxisLabel);
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', circleRadius)
  
  g.append('text')
    .attr('class','title')
  	.attr('y',-10)
  	.text(plotLabel);
};

  d3.csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
    .then(data => {
      data.forEach(d => {
        d.temperature = +d.temperature;
        d.timestamp = new Date(d.timestamp);
      });
      render(data);
    });